package
Version:
v0.0.0-...-1dfef78
Opens a new window with list of versions in this module.
Published: Feb 23, 2021
License: GPL-3.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DBConfig struct {
Engine string `json:"engine"`
Name string `json:"name"`
Host string `json:"host"`
Port uint `json:"port"`
User string `json:"user"`
Pass string `json:"pass"`
Refresh bool `json:"refresh"`
LogMode bool `json:"log_mode"`
}
type GSPConfig struct {
Port uint `json:"port"`
Pop bool `json:"pop"`
DBConfig *DBConfig `json:"db_config"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.